# IICS Secure Agent Docker Image

## Description

This project was forked from [jbrazda/ic-sagent-docker|https://github.com/jbrazda/ic-sagent-docker] with the intention of containerizing the IICS Secure Agent to run in Amazon Web Services.  As of early January 2019, there is no official Docker image for IICS Secure Agent.

## Requirements

* Docker
* An IICS user account and password for your organization that has appropriate rights to create and manage secure agents.  This user will be used to login to the Informatica APIs to register the agent.
* Your Informatica POD and REGION, which can be inferred from https://${POD}.${REGION}.informaticacloud.com/.  Defaults are set to POD=usw3 and REGION=dm-us, but can be overriden with Docker environment variables.

## The image

The image is based on Ubuntu 18.04.  It downloads and installs necessary dependencies, and then downloads the installer file from the correct Informatica URL based on your POD and REGION.

1. Clone this repository
2. `docker build . -t secure-agent`  Optionally pass --build-arg parameters for POD and REGION if the defaults are not correct.  POD and REGION are also set as environment variables, because containers will use these values for communicating with the Informatica API.

## Containers

The container executes a bash script called run_agent.sh upon start.  It needs INFORMATICA_USER and INFORMATICA_PASSWORD environment variables set during runtime in order to communicate with the Informatica API to check and register the Secure Agent.

### Environment variables

* INFORMATICA_USER (required) - User that can run the agent and access Informatica APIs
* INFORMATICA_PASSWORD (required) - Password for above credential.  Used for API access only.
* JSON_LOG (optional) - If this is set, then the log output will be in JSON format.

### Volumes

* Log files - tomcat log files are in the WORKDIR/logs directory.  agentcore.log and infaagent.log are in the WORKDIR directory
* Infaagent.ini - in WORKDIR/conf/infaagent.ini.  Contains the registration information for the secure agent
* data - Not sure what this does right now and whether this needs to be mounted as a volume.

### Starting

Setting the hostname will provide the associated name in the IICS web site.

`docker run -d -h <hostname> --env INFORMATICA_USER=xxxxx --env INFORMATICA_PASSWORD=xxxx --name <container_name> <image_name:image_tag>`

### Monitoring

```shell
docker exec -it ic-agent1 less agentCore.log
```

## Hardware requirements
From https://network.informatica.com/servlet/JiveServlet/download/189174-25674/Informatica%20Cloud%20Secure%20Agent%20Minimum%20Requirements.pdf
Minimum Hardware Specs
* Use one of the following operating systems:
* Windows version 7 (32-bit or 64-bit) or Windows XP Pro SP2/SP3 (32-bit).
* Linux (32-bit or 64-bit) with the following configuration:
* Red Hat Enterprise Linux version 5.3 or above.
* SUSE Linux Enterprise version 10 and above.
* 2-4 CPU recommended
* 2 GB RAM recommended dedicated for the Agent (Recent customers have used 8GB)
* 1 GB Hard disk space
* 1 GB Network connectivity (faster the better as this will most likely the bottleneck)

## Known Issues

* Doesn't seem to be able to run in host network mode because it won't be able to talk to internal ports.  It would probably work if you expose those ports.

## Terraform
* Infrastructure is available as code in terraform. 
* Before disposing and create a new instance of Informatica Secure Agent, existing live connections to various targets(for e.g. databases) 
should be reviewed and terminated. Due to this reason this is not part of CI/CD pipeline and can be executed as per necessity.
* Various configurations can be overridden using  `-var=`, see [variables.tf](./terraform/variables.tf) for available parameters.
```
$ cd terraform
$ terraform init
$ terraform validate
$ terraform plan -out agent.tfplan
$ terraform apply "agent.tfplan"
```
* See Terraform doc on [variables](https://www.terraform.io/docs/configuration/variables.html) to see how to pass command line arguments.